Learn R Programming

HRW (version 1.0-6)

SydneyRealEstateBdry: Polygonal boundary of Sydney

Description

A two-column data frame containing the (longitude,latitude) pairs for the vertices of a 202-sided polygon. The polygon was created manually using the HRW package function createBdry(). The polygon tightly encompasses the majority of the (longitude,latitude) data of the HRW package `SydneyRealEstate` data frame and approximately corresponds to the residential parts of Sydney, Australia.

Usage

data(SydneyRealEstateBdry)

Arguments

Format

A data frame with 203 observations on the following 2 variables (note that the first vertex is repeated at the end of the data frame):

longitude

longitudinal position of a vertex.

latitude

latitudinal position of the same vertex.

See Also

SydneyRealEstate

Examples

Run this code
library(HRW) ; data(SydneyRealEstateBdry) ; data(SydneyRealEstate)
plot(SydneyRealEstate$longitude,SydneyRealEstate$latitude,cex = 0.1)
lines(SydneyRealEstateBdry,lwd = 5,col = "red")

Run the code above in your browser using DataLab