Learn R Programming

HRW (version 1.0-6)

UtahPEF: Peak expiratory flow in Utah, U.S.A.

Description

The UtahPEF data frame data contains longitudinal data on peak expiratory flow, air pollution and temperature for a cohort of 41 schoolchildren in the Utah Valley, U.S.A., during 1990-1991.

Usage

data(UtahPEF)

Arguments

Format

This data frame contains the following columns:

idnum

schoolchild identification number.

devPEF

daily peak expiratory flow measurements for each schoolchild minus the overall average for that schoolchild.

PM10withMA5

5-day moving average of the concentration of particulate matter 10 micrometers or less in diameter.

lowTemp

lowest temperature in degrees Fahrenheit on the day of recording.

timeTrend

day of the study on which the measurements were made.

Examples

Run this code
library(HRW) ; data(UtahPEF)
if (require("lattice"))
   print(xyplot(devPEF ~ PM10withMA5|as.factor(idnum),data = UtahPEF))

Run the code above in your browser using DataLab