Learn R Programming

HRW (version 1.0-6)

coral: Coral organisms in French Polynesia

Description

The coral data frame has data on initial size, taxonomic identity and alive/death status of coral organisms in French Polynesia.

Usage

data(coral)

Arguments

Format

This data frame contains the following columns:

siteDepthPeriod

factor with levels corresponding to a code for the site, depth and time period concerning where and when coral organisms were measured.

taxon

factor corresponding to an abbreviation for taxonomic identity:
ACR = Acropora,
POC = Pocillopora,
POR = Porites.

logInitialSizePlusOne

initial size measurement of coral organism transformed according to the log(initial size + 1).

died

indicator that coral organism has died:
1 = coral organism has died,
0 = coral organism still alive.

Examples

Run this code
library(HRW) ; data(coral)
if (require("lattice"))
   print(xyplot(died ~ logInitialSizePlusOne|siteDepthPeriod*taxon,
                data = coral,layout = c(15,5)))

Run the code above in your browser using DataLab