Learn R Programming

HRW (version 1.0-6)

lidar: Light detection and ranging

Description

The lidar data frame has 221 pairs from a LIght Detection And Ranging (LIDAR) experiment.

Usage

data(lidar)

Arguments

Format

This data frame contains the following columns:

range

distance traveled before the light is reflected back to its source.

logratio

logarithm of the ratio of received light from two laser sources.

Examples

Run this code
library(HRW) ; data(lidar)
plot(lidar$range,lidar$logratio)

Run the code above in your browser using DataLab