Learn R Programming

HRW (version 1.0-6)

plankton: Flow cytometric measurements on plankton organisms

Description

The plankton data frame has data on six flow cytometric measurements for 400 plankton organisms categorized into 5 different species. The data are synthetic and were generated to test various machine learning algorithms for plankton species classification. More details are given in the 2001 `Cytometry' article by Boddy, Wilkins and Morris (full reference below).

Usage

data(plankton)

Arguments

Format

This data frame contains the following columns:

timeFlight

time of flight.

forwScatt

forward-scatter.

sideScatt

side-scatter.

redFluorBlueLight

red fluorescence under blue light.

greenFluorBlueLight

green fluorescence under blue light.

redFluorRedLight

red fluorescence under red light.

species

name of the plankton species, which is either Dunaliella, Hemiselmis, Isochrysis, Pavlova or Pyramimonas.

Examples

Run this code
library(HRW) ; data(plankton)
pointCols <- c("red","blue","green","orange","purple")
pairs(plankton[,1:6],col = pointCols[plankton$species],pch = ".")

Run the code above in your browser using DataLab