Learn R Programming

HRW (version 1.0-6)

ragweed: Ragweed pollen in Kalamazoo, U.S.A.

Description

The ragweed data frame has data on ragweed levels and meteorological variables for 334 days in Kalamazoo, Michigan, U.S.A.

Usage

data(ragweed)

Arguments

Format

This data frame contains the following columns:

pollenCount

ragweed pollen count (grains per cubic metre).

year

one of 1991, 1992, 1993 or 1994.

dayInSeason

day number in the current ragweed pollen season.

temperature

temperature for the corresponding day (degrees Fahrenheit).

temperatureResidual

residual from fitting a 5 effective degrees of freedom smoothing splines to temperature versus day number for each annual ragweed pollen season (degrees Fahrenheit).

rain

indicator of significant rain on the corresponding day:
1=at least 3 hours of steady or brief but intense rain,
0=otherwise.

windSpeed

wind speed for the corresponding day (knots).

References

Ruppert, D., Wand, M.P. and Carroll, R.J. (2003). Semiparametric Regression Cambridge University Press.

Examples

Run this code
library(HRW) ; data(ragweed)
pairs(ragweed,pch = ".")

Run the code above in your browser using DataLab