SydneyRealEstateBdry: Polygonal boundary of Sydney
Description
A two-column data frame containing the (longitude,latitude) pairs for the vertices of a 202-sided polygon. The polygon was created manually using the HRW package function createBdry(). The polygon tightly encompasses the majority of the (longitude,latitude) data of the HRW package `SydneyRealEstate` data frame and approximately corresponds to the residential parts of Sydney, Australia.
Usage
data(SydneyRealEstateBdry)
Arguments
Format
A data frame with 203 observations on the following 2 variables (note that the first vertex is repeated at the end of the data frame):