powered by
The lidar data frame has 221 pairs from a LIght Detection And Ranging (LIDAR) experiment.
lidar
data(lidar)
This data frame contains the following columns:
range
distance traveled before the light is reflected back to its source.
logratio
logarithm of the ratio of received light from two laser sources.
library(HRW) ; data(lidar) plot(lidar$range,lidar$logratio)
Run the code above in your browser using DataLab