powered by
The protein data frame has longitudinal data on protein intake, body mass index and age of subjects in a dietary study.
protein
data(protein)
This data frame contains the following columns:
idnum
identification number unique to each subject.
proteinBioM
logarithm of intake of protein as measured by the biomarker urinary.
age
age of subject in years.
BMI
body mass index.
proteinRecall
logarithm of intake of protein as measured by a 24-hour recall instrument.
female
indicator that subject is female: 1=subject is female, 0=subject is male.
library(HRW) ; data(protein) if (require("lattice")) print(xyplot(proteinBioM ~ BMI|factor(female),groups = idnum, data = protein, type = "b"))
Run the code above in your browser using DataLab