powered by
The schoolResults data frame has multilevel data school results and gender for 1,905 school children from 73 schools in United Kingdom.
schoolResults
data(schoolResults)
This data frame contains the following columns:
schoolID
school identification number.
studentID
student identification number.
indicator that child is female: 1=child is female, 0=child is male.
writtenScore
score on traditional written examination paper out of a total of 160.
courseScore
score from projects undertaken during the course and marked by the student's own teacher, out of a total of 108.
library(HRW) ; data(schoolResults) if (require("lattice")) print(xyplot(writtenScore ~ courseScore|factor(schoolID), groups = female,data = schoolResults))
Run the code above in your browser using DataLab